﻿using System;
using System.Threading;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;
using System.ServiceModel.Description;
using System.ServiceModel.Activities;
using System.Activities;
using System.Activities.Statements;

namespace Articles.Workflow.SendReceiveWorkflowService
{
    public static class Program
    {
        /// <summary>
        /// Main method of the application.
        /// </summary>
        public static void Main(string[] args)
        {
            string baseAddress = "http://localhost:5020/CustomService";
            using (WorkflowServiceHost host = new WorkflowServiceHost(new MainActivity(), new Uri(baseAddress)))
            {
                //Auto generation of wsdl files
                host.Description.Behaviors.Add(new ServiceMetadataBehavior() { HttpGetEnabled = true });

                //Go into listening state
                host.Open();
                Console.WriteLine("CustomService waiting at: {0}", baseAddress);
                Console.WriteLine("Press [ENTER] to exit or type a message to send it to the service.");
                Console.WriteLine();

                //Start a short loop for calling the webservice
                string input = string.Empty;
                string serviceResult = string.Empty;
                Console.Write(">> ");
                while (!string.IsNullOrEmpty(input = Console.ReadLine()))
                {
                    //Call workflow service
                    Stopwatch stopwatch = new Stopwatch();
                    stopwatch.Start();
                    {
                        SelfService.CustomServiceClient serviceClient = new SelfService.CustomServiceClient();
                        serviceResult = serviceClient.DoSomething(input);
                    }
                    stopwatch.Stop();

                    //Show result
                    Console.WriteLine("Called service and received: " + serviceResult);
                    Console.WriteLine("Call took {0}ms", stopwatch.ElapsedMilliseconds);
                    Console.WriteLine();

                    //Prepare next input
                    Console.Write(">> ");
                }

                //Close service host
                host.Close();
            }
        }
    }
}
